==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DevicePolicyRuleConditionPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyMDMFramework;
import com.okta.sdk.resource.model.DevicePolicyPlatformType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DevicePolicyRuleConditionPlatform
 */
@JsonPropertyOrder({ DevicePolicyRuleConditionPlatform.JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS,
        DevicePolicyRuleConditionPlatform.JSON_PROPERTY_TYPES })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class DevicePolicyRuleConditionPlatform implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS = "supportedMDMFrameworks";
    private List<DevicePolicyMDMFramework> supportedMDMFrameworks = null;

    public static final String JSON_PROPERTY_TYPES = "types";
    private List<DevicePolicyPlatformType> types = null;

    public DevicePolicyRuleConditionPlatform() {
    }

    public DevicePolicyRuleConditionPlatform supportedMDMFrameworks(
            List<DevicePolicyMDMFramework> supportedMDMFrameworks) {

        this.supportedMDMFrameworks = supportedMDMFrameworks;
        return this;
    }

    public DevicePolicyRuleConditionPlatform addsupportedMDMFrameworksItem(
            DevicePolicyMDMFramework supportedMDMFrameworksItem) {
        if (this.supportedMDMFrameworks == null) {
            this.supportedMDMFrameworks = new ArrayList<>();
        }
        this.supportedMDMFrameworks.add(supportedMDMFrameworksItem);
        return this;
    }

    /**
     * Get supportedMDMFrameworks
     *
     * @return supportedMDMFrameworks
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DevicePolicyMDMFramework> getSupportedMDMFrameworks() {
        return supportedMDMFrameworks;
    }

    @JsonProperty(JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSupportedMDMFrameworks(List<DevicePolicyMDMFramework> supportedMDMFrameworks) {
        this.supportedMDMFrameworks = supportedMDMFrameworks;
    }

    public DevicePolicyRuleConditionPlatform types(List<DevicePolicyPlatformType> types) {

        this.types = types;
        return this;
    }

    public DevicePolicyRuleConditionPlatform addtypesItem(DevicePolicyPlatformType typesItem) {
        if (this.types == null) {
            this.types = new ArrayList<>();
        }
        this.types.add(typesItem);
        return this;
    }

    /**
     * Get types
     *
     * @return types
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DevicePolicyPlatformType> getTypes() {
        return types;
    }

    @JsonProperty(JSON_PROPERTY_TYPES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTypes(List<DevicePolicyPlatformType> types) {
        this.types = types;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DevicePolicyRuleConditionPlatform devicePolicyRuleConditionPlatform = (DevicePolicyRuleConditionPlatform) o;
        return Objects.equals(this.supportedMDMFrameworks, devicePolicyRuleConditionPlatform.supportedMDMFrameworks)
                && Objects.equals(this.types, devicePolicyRuleConditionPlatform.types);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(supportedMDMFrameworks, types);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DevicePolicyRuleConditionPlatform {\n");
        sb.append("    supportedMDMFrameworks: ").append(toIndentedString(supportedMDMFrameworks)).append("\n");
        sb.append("    types: ").append(toIndentedString(types)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DevicePolicyRuleConditionPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyMDMFramework;
import com.okta.sdk.resource.model.DevicePolicyPlatformType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DevicePolicyRuleConditionPlatform
 */
@JsonPropertyOrder({ DevicePolicyRuleConditionPlatform.JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS,
        DevicePolicyRuleConditionPlatform.JSON_PROPERTY_TYPES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class DevicePolicyRuleConditionPlatform implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS = "supportedMDMFrameworks";
    private List<DevicePolicyMDMFramework> supportedMDMFrameworks = null;

    public static final String JSON_PROPERTY_TYPES = "types";
    private List<DevicePolicyPlatformType> types = null;

    public DevicePolicyRuleConditionPlatform() {
    }

    public DevicePolicyRuleConditionPlatform supportedMDMFrameworks(
            List<DevicePolicyMDMFramework> supportedMDMFrameworks) {

        this.supportedMDMFrameworks = supportedMDMFrameworks;
        return this;
    }

    public DevicePolicyRuleConditionPlatform addsupportedMDMFrameworksItem(
            DevicePolicyMDMFramework supportedMDMFrameworksItem) {
        if (this.supportedMDMFrameworks == null) {
            this.supportedMDMFrameworks = new ArrayList<>();
        }
        this.supportedMDMFrameworks.add(supportedMDMFrameworksItem);
        return this;
    }

    /**
     * Get supportedMDMFrameworks
     *
     * @return supportedMDMFrameworks
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DevicePolicyMDMFramework> getSupportedMDMFrameworks() {
        return supportedMDMFrameworks;
    }

    @JsonProperty(JSON_PROPERTY_SUPPORTED_M_D_M_FRAMEWORKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSupportedMDMFrameworks(List<DevicePolicyMDMFramework> supportedMDMFrameworks) {
        this.supportedMDMFrameworks = supportedMDMFrameworks;
    }

    public DevicePolicyRuleConditionPlatform types(List<DevicePolicyPlatformType> types) {

        this.types = types;
        return this;
    }

    public DevicePolicyRuleConditionPlatform addtypesItem(DevicePolicyPlatformType typesItem) {
        if (this.types == null) {
            this.types = new ArrayList<>();
        }
        this.types.add(typesItem);
        return this;
    }

    /**
     * Get types
     *
     * @return types
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<DevicePolicyPlatformType> getTypes() {
        return types;
    }

    @JsonProperty(JSON_PROPERTY_TYPES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTypes(List<DevicePolicyPlatformType> types) {
        this.types = types;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DevicePolicyRuleConditionPlatform devicePolicyRuleConditionPlatform = (DevicePolicyRuleConditionPlatform) o;
        return Objects.equals(this.supportedMDMFrameworks, devicePolicyRuleConditionPlatform.supportedMDMFrameworks)
                && Objects.equals(this.types, devicePolicyRuleConditionPlatform.types);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(supportedMDMFrameworks, types);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DevicePolicyRuleConditionPlatform {\n");
        sb.append("    supportedMDMFrameworks: ").append(toIndentedString(supportedMDMFrameworks)).append("\n");
        sb.append("    types: ").append(toIndentedString(types)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
